@@ -186,6 +186,9 @@ def typogrify(xhtml: str, smart_quotes: bool = True) -> str:
 
 	xhtml = regex.sub(r"([0-9]+)\s<abbr", fr"\1{se.NO_BREAK_SPACE}<abbr", xhtml)
 
+	# Add rsquo to bare `tis` and `twas`
+	xhtml = regex.sub(r"([^’>])\b([Tt]is|[Tt]was|[Tt]were|[Tt]won’t)\b", r"\1’\2", xhtml)
+
 	# A note on spacing:
 	# 					ibooks	kindle (mobi7)
 	# thin space U+2009:			yes	yes
@@ -200,7 +203,7 @@ def typogrify(xhtml: str, smart_quotes: bool = True) -> str:
 	# Years
 	xhtml = regex.sub(r"‘([0-9]{2,}[^\p{Letter}0-9’])", r"’\1", xhtml, flags=regex.IGNORECASE)
 
-	xhtml = regex.sub(r"‘([Aa]ve|[Oo]me|[Ii]m|[Mm]idst|[Gg]ainst|[Nn]eath|[Ee]m|[Cc]os|[Tt]is|[Tt]isn’t|[Tt]was|[Tt]wixt|[Tt]were|[Tt]would|[Tt]wouldn|[Tt]ween|[Tt]will|[Rr]ound|[Pp]on|[Uu]ns?|[Uu]d|[Cc]ept|[Oo]w|[Aa]ppen|[Ee])\b", r"’\1", xhtml)
+	xhtml = regex.sub(r"‘([Aa]ve|[Oo]me|[Ii]m|[Mm]idst|[Gg]ainst|[Nn]eath|[Ee]m|[Cc]os|[Tt]is|[Tt]isn’t|[Tt]was|[Tt]wixt|[Tt]were|[Tt]would|[Tt]wouldn|[Tt]won|[Tt]ween|[Tt]will|[Rr]ound|[Pp]on|[Uu]ns?|[Uu]d|[Cc]ept|[Oo]w|[Aa]ppen|[Ee])\b", r"’\1", xhtml)
 
 	xhtml = regex.sub(r"\b‘e\b", r"’e", xhtml)
 	xhtml = regex.sub(r"\b‘([Ee])r\b", r"’\1r", xhtml)
@@ -458,21 +461,18 @@ def guess_quoting_style(xhtml: str) -> str:
 	# Quote style percentage above the threshold is returned.
 	threshold = 80
 
-	lsq_count = len([m for m in regex.findall(r"\t*<p>(.*?)‘", xhtml) if m.count("“") == 0])
-	ldq_count = len([m for m in regex.findall(r"\t*<p>(.*?)“", xhtml) if m.count("‘") == 0])
-
+	ldq_count = len([m for m in regex.findall(r"\t*<p[^>]*>(.*?)“", xhtml) if m.count("‘") == 0])
+	lsq_count = len([m for m in regex.findall(r"\t*<p[^>]*>(.*?)‘", xhtml) if m.count("“") == 0])
 	detected_style = "unsure"
-	american_percentage = 0
 
-	try:
-		american_percentage = int(ldq_count / (ldq_count + lsq_count) * 100)
-	except ZeroDivisionError:
-		pass
+	if (ldq_count + lsq_count) != 0:
+		american_percentage = int((ldq_count / (ldq_count + lsq_count)) * 100)
+		british_percentage = int((lsq_count / (ldq_count + lsq_count)) * 100)
 
-	if american_percentage >= threshold:
-		detected_style = "american"
-	elif 100 - american_percentage >= threshold:
-		detected_style = "british"
+		if american_percentage >= threshold:
+			detected_style = "american"
+		elif british_percentage >= threshold:
+			detected_style = "british"
 
 	return detected_style
 
